@@ -24,8 +24,10 @@
 #' units). See details below.
 #' @param ... For [select_by_one_std_err()] and [select_by_pct_loss()], this
 #' argument is passed directly to [dplyr::arrange()] so that the user can sort
-#' the models from *most simple to most complex*. See the examples below. At
-#' least one term is required for these two functions.
+#' the models from *most simple to most complex*. That is, for a parameter `p`,
+#' pass the unquoted expression `p` if smaller values of `p` indicate a simpler
+#' model, or `desc(p)` if larger values indicate a simpler model. At
+#' least one term is required for these two functions. See the examples below.
 #' @return A tibble with columns for the parameters. [show_best()] also
 #'  includes columns for performance metrics.
 #' @details
@@ -35,8 +37,7 @@
 #' @references
 #' Breiman, Leo; Friedman, J. H.; Olshen, R. A.; Stone, C. J. (1984).
 #' _Classification and Regression Trees._ Monterey, CA: Wadsworth.
-#' @examples
-#' \donttest{
+#' @examplesIf tune:::should_run_examples()
 #' data("example_ames_knn")
 #'
 #' show_best(ames_iter_search, metric = "rmse")
@@ -56,7 +57,6 @@
 #'   metric = "rmse",
 #'   limit = 5, desc(K)
 #' )
-#' }
 #' @export
 show_best <- function(x, ...) {
   UseMethod("show_best")
@@ -79,7 +79,7 @@ show_best.tune_results <- function(x, metric = NULL, n = 5, ...) {
       "This value was ignored."
     ))
   }
-  maximize <- is_metric_maximize(x, metric)
+  direction <- get_metric_direction(x, metric)
   summary_res <- estimate_tune_results(x)
   metrics <- unique(summary_res$.metric)
   if (length(metrics) == 1) {
@@ -93,10 +93,12 @@ show_best.tune_results <- function(x, metric = NULL, n = 5, ...) {
     rlang::abort("No results are available. Please check the value of `metric`.")
   }
 
-  if (maximize) {
+  if (direction == "maximize") {
     summary_res <- summary_res %>% dplyr::arrange(dplyr::desc(mean))
-  } else {
+  } else if (direction == "minimize") {
     summary_res <- summary_res %>% dplyr::arrange(mean)
+  } else if (direction == "zero") {
+    summary_res <- summary_res %>% dplyr::arrange(abs(mean))
   }
   show_ind <- 1:min(nrow(summary_res), n)
   summary_res %>% dplyr::slice(show_ind)
@@ -176,7 +178,7 @@ select_by_pct_loss.tune_results <- function(x, ..., metric = NULL, limit = 2) {
   if (length(dots) == 0) {
     rlang::abort("Please choose at least one tuning parameter to sort in `...`.")
   }
-  maximize <- is_metric_maximize(x, metric)
+  direction <- get_metric_direction(x, metric)
   res <-
     collect_metrics(x) %>%
     dplyr::filter(.metric == !!metric & !is.na(mean))
@@ -184,38 +186,40 @@ select_by_pct_loss.tune_results <- function(x, ..., metric = NULL, limit = 2) {
   if (nrow(res) == 0) {
     rlang::abort("No results are available. Please check the value of `metric`.")
   }
-  if (maximize) {
+  if (direction == "maximize") {
     best_metric <- max(res$mean, na.rm = TRUE)
-    res <-
-      res %>%
-      dplyr::mutate(
-        .best = best_metric,
-        .loss = (best_metric - mean) / best_metric * 100
-      )
-  } else {
+  } else if (direction == "minimize") {
     best_metric <- min(res$mean, na.rm = TRUE)
-    res <-
-      res %>%
-      dplyr::mutate(
-        .best = best_metric,
-        .loss = (mean - best_metric) / best_metric * 100
-      )
+  } else if (direction == "zero") {
+    which_min <- which.min(abs(res$mean))
+    best_metric <- res$mean[which_min]
   }
 
+  res <-
+    res %>%
+    dplyr::rowwise() %>%
+    dplyr::mutate(
+      .best = best_metric,
+      # can calculate loss without knowledge of direction since
+      # we know that losses must be larger than that for the best
+      .loss = abs((abs(mean) - abs(.best)) / .best) * 100
+    ) %>%
+    dplyr::ungroup()
+
   res <- try(dplyr::arrange(res, !!!dots), silent = TRUE)
   if (inherits(res, "try-error")) {
     var_nm <- rlang::eval_tidy(dots)
-    var_nm <- purrr::map_chr(var_nm, ~ as.character(rlang::quo_get_expr(.x)))
-    msg <- paste0("Could not sort results by '", var_nm, "'.")
-    rlang::abort(msg)
+    var_nm <- purrr::map_chr(var_nm, ~ rlang::quo_name(.x))
+    var_nm <- var_nm[!var_nm %in% colnames(collect_metrics(x))]
+    cli::cli_abort("Could not sort results by {.var {var_nm}}.")
   }
 
-  # discard models more complex than the best then rank by loss
+  # discard models more complex than the best and
+  # remove models with greater increase in loss than the limit
   best_index <- which(res$.loss == 0)
   res %>%
     dplyr::slice(1:best_index) %>%
     dplyr::filter(.loss < limit) %>%
-    dplyr::arrange(desc(.loss)) %>%
     dplyr::slice(1)
 }
 
@@ -246,7 +250,7 @@ select_by_one_std_err.tune_results <- function(x, ..., metric = NULL) {
   if (length(dots) == 0) {
     rlang::abort("Please choose at least one tuning parameter to sort in `...`.")
   }
-  maximize <- is_metric_maximize(x, metric)
+  direction <- get_metric_direction(x, metric)
   res <-
     collect_metrics(x) %>%
     dplyr::filter(.metric == !!metric & !is.na(mean))
@@ -255,7 +259,7 @@ select_by_one_std_err.tune_results <- function(x, ..., metric = NULL) {
     rlang::abort("No results are available. Please check the value of `metric`.")
   }
 
-  if (maximize) {
+  if (direction == "maximize") {
     best_index <- which.max(res$mean)
     best <- res$mean[best_index]
     bound <- best - res$std_err[best_index]
@@ -266,7 +270,7 @@ select_by_one_std_err.tune_results <- function(x, ..., metric = NULL) {
         .bound = bound
       ) %>%
       dplyr::filter(mean >= .bound)
-  } else {
+  } else if (direction == "minimize") {
     best_index <- which.min(res$mean)
     best <- res$mean[best_index]
     bound <- best + res$std_err[best_index]
@@ -277,19 +281,33 @@ select_by_one_std_err.tune_results <- function(x, ..., metric = NULL) {
         .bound = bound
       ) %>%
       dplyr::filter(mean <= .bound)
+  } else if (direction == "zero") {
+    best_index <- which.min(abs(res$mean))
+    best <- res$mean[best_index]
+    bound_lower <- -abs(best) - res$std_err[best_index]
+    bound_upper <- abs(best) + res$std_err[best_index]
+    res <-
+      res %>%
+      dplyr::rowwise() %>%
+      dplyr::mutate(
+        .best = best,
+        .bound = list(c(lower = bound_lower, upper = bound_upper))
+      ) %>%
+      dplyr::filter(mean >= .bound[[1]] & mean <= .bound[[2]]) %>%
+      dplyr::ungroup()
   }
 
   res <- try(dplyr::arrange(res, !!!dots), silent = TRUE)
   if (inherits(res, "try-error")) {
     var_nm <- rlang::eval_tidy(dots)
-    var_nm <- purrr::map_chr(var_nm, ~ as.character(rlang::quo_get_expr(.x)))
-    msg <- paste0("Could not sort results by '", var_nm, "'.")
-    rlang::abort(msg)
+    var_nm <- purrr::map_chr(var_nm, ~ rlang::quo_name(.x))
+    var_nm <- var_nm[!var_nm %in% colnames(collect_metrics(x))]
+    cli::cli_abort("Could not sort results by {.var {var_nm}}.")
   }
   res %>% dplyr::slice(1)
 }
 
-is_metric_maximize <- function(x, metric) {
+get_metric_direction <- function(x, metric) {
   if (rlang::is_missing(metric) | length(metric) > 1) {
     rlang::abort("Please specify a single character value for `metric`.")
   }
@@ -303,5 +321,5 @@ is_metric_maximize <- function(x, metric) {
     attr("metrics") %>%
     purrr::map(~ attr(.x, "direction"))
 
-  directions[[metric]] == "maximize"
+  directions[[metric]]
 }
